@@ -69,7 +69,6 @@ class Inferences(object):
                 data.optimize(*args)
             
         if self.method == "DSC":
-            print("W", data.w)
             self._update_original_data(placebo)
 
         return
@@ -163,7 +162,7 @@ class Inferences(object):
                             control_placebo_outcome[:data.periods_pre_treatment], 
                             control_placebo_covariates,
                             data,
-                            "in-space", 4)
+                            "in-space", 3)
             
             #Compute outcome of best synthetic control
             if self.method == "SC":
@@ -248,19 +247,21 @@ class Inferences(object):
         include_donor_pool_average: bool. Default=False.
         Whether or not include a third column with the simple average for the entire donor pool.
         '''
-        
+
+        data = self.original_data
+
         if not include_donor_pool_average:
             
-            table = pd.DataFrame({treated_label: self.treated_covariates.ravel(), 
-                                 synth_label: (self.synth_covariates).ravel()},
-                                index=self.covariates)
+            table = pd.DataFrame({treated_label: data.treated_covariates.ravel(), 
+                                 synth_label: (data.synth_covariates).ravel()},
+                                index=data.covariates)
         
         else:
             
-            table = pd.DataFrame({treated_label: self.treated_covariates.ravel(), 
-                                 synth_label: (self.synth_covariates).ravel(),
-                                 donor_pool_label: self.control_covariates.mean(axis=1)},
-                                index=self.covariates)
+            table = pd.DataFrame({treated_label: data.treated_covariates.ravel(), 
+                                 synth_label: (data.synth_covariates).ravel(),
+                                 donor_pool_label: data.control_covariates.mean(axis=1)},
+                                index=data.covariates)
         return table
 
     def _normalize_placebos(self, placebo_outcomes):
@@ -282,7 +283,7 @@ class Inferences(object):
 
         return normalized_placebo_outcomes
 
-    def _pre_post_rmspe_ratios(self, placebo_outcomes):
+    def _pre_post_rmspe_ratios(self, placebo_outcomes, placebo=True):
         '''
         Computes the pre-post root mean square prediction error for all
         in-place placebos and the treated units
@@ -293,27 +294,42 @@ class Inferences(object):
         post_ratio_list, pre_ratio_list = [], []
 
         #Add treated unit
-        treated_post, treated_pre = self._pre_post_rmspe(data.synth_outcome.T, data.treated_outcome_all)
-        post_ratio_list.append(treated_post)
-        pre_ratio_list.append(treated_pre)
+        if not placebo:
+            #Compute rmspe
+            treated_post, treated_pre = self._pre_post_rmspe(data.synth_outcome.T, data.treated_outcome_all)
+            post_ratio_list.append(treated_post)
+            pre_ratio_list.append(treated_pre)
 
+            #Store in dataframe
+            rmspe_df = pd.DataFrame({"pre_rmspe": pre_ratio_list,
+                                    "post_rmspe": post_ratio_list},
+                                    columns=["pre_rmspe", "post_rmspe"])
+            #Compute post/pre rmspe ratio
+            rmspe_df["post/pre"] = rmspe_df["post_rmspe"] / rmspe_df["pre_rmspe"]
 
-        #Add each control unit and respective synthetic control
-        for i in range(data.n_controls):
-            post_ratio, pre_ratio = self._pre_post_rmspe(placebo_outcomes[i], data.control_outcome_all[:, i].T, placebo=True)
-            post_ratio_list.append(post_ratio)
-            pre_ratio_list.append(pre_ratio)
+            data.rmspe_df = rmspe_df
+            return
+            
 
-        #Combine in Dataframe
-        rmspe_df = pd.DataFrame({"pre_rmspe": pre_ratio_list,
-                                "post_rmspe": post_ratio_list},
-                                columns=["pre_rmspe", "post_rmspe"])
-        #Compute post/pre rmspe ratio
-        rmspe_df["post/pre"] = rmspe_df["post_rmspe"] / rmspe_df["pre_rmspe"]
-        
-        #Return dataframe object
-        return rmspe_df
+        else: #if placebo
+            #Add each control unit and respective synthetic control
+            for i in range(data.n_controls):
+                post_ratio, pre_ratio = self._pre_post_rmspe(placebo_outcomes[i], data.control_outcome_all[:, i].T, placebo=True)
+                post_ratio_list.append(post_ratio)
+                pre_ratio_list.append(pre_ratio)
 
+            #Store in dataframe
+            rmspe_df = pd.DataFrame({"pre_rmspe": pre_ratio_list,
+                                    "post_rmspe": post_ratio_list},
+                                    columns=["pre_rmspe", "post_rmspe"])
+            
+            #Compute post/pre rmspe ratio
+            rmspe_df["post/pre"] = rmspe_df["post_rmspe"] / rmspe_df["pre_rmspe"]
+            
+            #Extend self.original_data.rmspe_df and return
+            data.rmspe_df = pd.concat([data.rmspe_df, rmspe_df], axis=0)
+            return
+             
 
     def _pre_post_rmspe(self, synth_outcome, treated_outcome, placebo=False):
         '''
